@@ -69,6 +69,28 @@ class GenericResolveUIDDeserializer(object):
             return link
 
 
+class TableResolveUIDDeserializer(object):
+    """ """
+
+    order = 210  # after standard ones
+    block_type = "table"
+
+    def __init__(self, context, request):
+        self.context = context
+        self.request = request
+
+    def __call__(self, block):
+        for row in block.get("table", {}).get("rows", []):
+            for cell in row.get("cells", []):
+                for entity in cell.get("value", {}).get("entityMap", {}).values():
+                    if entity.get("type") == "LINK":
+                        href = entity.get("data", {}).get("url", "")
+                        entity["data"]["url"] = path2uid(
+                            context=self.context, link=href
+                        )
+        return block
+
+
 @implementer(IBlockFieldDeserializationTransformer)
 @adapter(IBlocks, IRedturtleVoltoLayer)
 class GenericResolveUIDDeserializerContents(GenericResolveUIDDeserializer):
@@ -79,3 +101,15 @@ class GenericResolveUIDDeserializerContents(GenericResolveUIDDeserializer):
 @adapter(IPloneSiteRoot, IRedturtleVoltoLayer)
 class GenericResolveUIDDeserializerRoot(GenericResolveUIDDeserializer):
     """Deserializer for site-root"""
+
+
+@implementer(IBlockFieldDeserializationTransformer)
+@adapter(IBlocks, IRedturtleVoltoLayer)
+class TableResolveUIDDeserializerContents(TableResolveUIDDeserializer):
+    """Deserializer for content-types that implements IBlocks behavior"""
+
+
+@implementer(IBlockFieldDeserializationTransformer)
+@adapter(IPloneSiteRoot, IRedturtleVoltoLayer)
+class TableResolveUIDDeserializerRoot(TableResolveUIDDeserializer):
+    """Deserializer for site-root"""
